Package: wallace
Version: 2.2.1
Date: 2026-05-05
Title: A Modular Platform for Reproducible Modeling of Species Niches
        and Distributions
Description: The 'shiny' application Wallace is a modular platform for 
    reproducible modeling of species niches and distributions. Wallace
    guides users through a complete analysis, from the acquisition of species
    occurrence and environmental data to visualizing model predictions on an 
    interactive map, thus bundling complex workflows into a single, 
    streamlined interface. An extensive vignette, which guides users through 
    most package functionality can be found on the package's GitHub Pages 
    website: <https://wallaceecomod.github.io/wallace/articles/tutorial-v2.html>.
Authors@R: 
    c(person("Daniel F.", "Lopez-Lozano", email = "dlopezlozano@amnh.org", role = "aut"),
    person("Bethany A.", "Johnson", email = "bjohnso005@citymail.cuny.edu", role = "aut"),
    person("Jamie M.", "Kass", email = "jamie.m.kass@gmail.com", role = "aut"),
    person("Gonzalo E.", "Pinilla-Buitrago", email = "gepinillab@gmail.com", role = "aut"),
    person("Andrea", "Paz", email = "paz.andreita@gmail.com", role = "aut"),
    person("Valentina", "Grisales-Betancur", email = "vgrisale@eafit.edu.co", role = "aut"),
    person("Dean", "Attali", email = "daattali@gmail.com", role = "aut"),
    person("Matthew E.", "Aiello-Lammens", email = "matt.lammens@gmail.com", role = "aut"),
    person("Cory", "Merow", email = "corymerow@gmail.com", role = "aut"),
    person("Mary E.", "Blair", email = "mblair1@amnh.org", role = c("aut", "cre")),
    person("Robert P.", "Anderson", email = "randerson@ccny.cuny.edu", role = "aut"),
    person("Sarah I.", "Meenan", email = "sarah.meenan@gmail.com", role = "ctb"),
    person("Olivier", "Broennimann", email = "olivier.broennimann@unil.ch", role = "ctb"),
    person("Peter J.", "Galante", email = "pgalante@amnh.org", role = "ctb"),
    person("Brian S.", "Maitner", email = "bmaitner@gmail.com", role = "ctb"),
    person("Hannah L.", "Owens", email = "hannah.owens@gmail.com", role = "ctb"),
    person("Sara", "Varela", email = "sara_varela@yahoo.com", role = "ctb"),
    person("Bruno", "Vilela", email = "bvilela@wustl.edu", role = "ctb"),
    person("Robert", "Muscarella", email = "bob.muscarella@gmail.com", role = "ctb"))
Depends: R (>= 3.5.0), shiny (>= 1.6.0), leaflet (>= 2.0.2)
Imports: dplyr (>= 1.0.2), DT (>= 0.5), ecospat (>= 4.0.0), ENMeval (>=
        2.0.5), geodata, htmltools, knitcitations, leafem, magrittr,
        markdown, RColorBrewer, rJava, rlang, rmarkdown, sf,
        shinyalert, shinyjs, shinyWidgets (>= 0.6.0), spocc (>= 1.2.0),
        spThin, zip
Suggests: ade4, BIEN, dismo, glue, jsonlite, knitr, mapview, maxnet,
        occCite, predicts, rangeModelMetadata, raster, rgbif (>=
        3.3.0), sp, terra (>= 1.9-11), testthat, tools
License: GPL-3
URL: https://wallaceecomod.github.io/wallace/
Encoding: UTF-8
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-05-07 11:50:38 UTC; dlopezlozano
Author: Daniel F. Lopez-Lozano [aut],
  Bethany A. Johnson [aut],
  Jamie M. Kass [aut],
  Gonzalo E. Pinilla-Buitrago [aut],
  Andrea Paz [aut],
  Valentina Grisales-Betancur [aut],
  Dean Attali [aut],
  Matthew E. Aiello-Lammens [aut],
  Cory Merow [aut],
  Mary E. Blair [aut, cre],
  Robert P. Anderson [aut],
  Sarah I. Meenan [ctb],
  Olivier Broennimann [ctb],
  Peter J. Galante [ctb],
  Brian S. Maitner [ctb],
  Hannah L. Owens [ctb],
  Sara Varela [ctb],
  Bruno Vilela [ctb],
  Robert Muscarella [ctb]
Maintainer: Mary E. Blair <mblair1@amnh.org>
Repository: CRAN
Date/Publication: 2026-05-07 14:40:54 UTC
Built: R 4.5.2; ; 2026-05-07 16:44:38 UTC; unix
