# Generated by roxygen2: do not edit by hand

export(addDrawToolbar)
export(clearAll)
export(create_module)
export(ecoClimate_getdata)
export(ecoClimate_select)
export(ecospat.plot.nicheDEV)
export(editToolbarOptions)
export(envs_ecoClimate)
export(envs_userEnvs)
export(envs_worldclim)
export(espace_nicheOv)
export(espace_occDens)
export(espace_pca)
export(fmtSpN)
export(getRasterVals)
export(hlSpp)
export(model_bioclim)
export(model_maxent)
export(mxNonzeroCoefs)
export(occs_queryDb)
export(occs_userOccs)
export(part_partitionOccs)
export(penvs_bgExtent)
export(penvs_bgMask)
export(penvs_bgSample)
export(penvs_drawBgExtent)
export(penvs_userBgExtent)
export(poccs_removeByID)
export(poccs_selectOccs)
export(poccs_thinOccs)
export(polyZoom)
export(popUpContent)
export(predictMaxnet)
export(printVecAsis)
export(register_module)
export(remEnvsValsNA)
export(removeDrawToolbar)
export(reverseLabel)
export(run_wallace)
export(smartProgress)
export(spName)
export(spurious)
export(vis_bioclimPlot)
export(writeLog)
export(write_csv_robust)
export(xfer_area)
export(xfer_draw)
export(xfer_mess)
export(xfer_time)
export(xfer_userEnvs)
export(xfer_userExtent)
export(zoom2Occs)
import(leaflet)
import(shiny)
importFrom(magrittr,"%>%")
importFrom(rlang,.data)
