Wallace is a wrapper for database adapters. We offer a mini-ORM,
extensions to common connection classes (without obscuring driver libraries),
and a cache for connection pool sharing. Currently supports
PostgreSQL/psycopg2, Redis/redis-py, and MongoDB/pymongo (more to come).
Thanks for taking a look.
