---
title: "How To Use Wallace"
output: html_document
---

### **Overview of** ***Wallace***
This information is designed to orient the user to the *Wallace* interface. For detailed instructions and a sample walkthrough, please consult the <a href="https://wallaceecomod.github.io/wallace/articles/tutorial-v2.html" target="_blank">vignette</a>.  

*Para obtener instrucciones detalladas y un tutorial de muestra en español, consulte <a href="https://wallaceecomod.github.io/wallace/articles/tutorial-v2-esp.html" target="_blank">la viñeta en español</a>.*

#### **Components and Modules**
*Wallace* is composed of **Components** – discrete steps in the workflow. Navigate through the components by clicking on the names in the top orange navigation panel. Components need to be run consecutively, but a few are optional (e.g., **Env Space**).  
  
Within each component, there are various major options that can be run. These are the ***modules***. Selecting a module opens the control panel to make decisions and run the module’s functionalities. For some components, the modules are mutually exclusive (e.g., in **Env Data**, only one choice can be selected), but in others this is not the case (e.g., in **Process Occs**, all three modules can be run successively).  
  
#### **Log Window and Visualization Panel**
Analyses performed will be detailed in the log window. This is also where error messages appear.

After running the functionalities of a *module*, outputs appear in the Visualization panel, which includes an interactive map, Occurrence table, and the Results tab, as relevant. The Visualization panel also includes guidance texts and the Save tab (see below).

#### **Guidance Texts**
While Wallace makes it easy to perform analyses through the workflow of its Graphical User Interface (GUI) without coding, the theory and methodologies behind the decisions should be considered carefully (Kass et al. 2018). The title of one essay aimed at students and researchers entering the field put it more bluntly: ‘Modeling niches and distributions: it's not just "click, click, click"’ (Anderson, 2015). Wallace aims to fulfill the call for software in the field that automates “repetitive aspects of the process, while allowing (and forcing) the user to provide input when critical biological and conceptual decisions need to be made” (Anderson, 2012: p. 77).

Wallace promotes thought and careful decision making by offering guidance text for each component and module to orient the user and assist in best practices. To understand the analyses run in Wallace and be able to explain and justify them, users likely will need to read relevant literature and discuss many issues extensively with their peers. An enormous literature now exists regarding models of species niches and distributions (Franklin 2010, Peterson et al. 2011, Guisan et al. 2017, Zurell et al. 2020). To facilitate entry into this literature, the Wallace guidance text points users toward some sources relevant to the given component or module. Additionally, extensive open-access online resources exist (e.g., free lectures from the ENM2020 course; Peterson et al. 2022).

As the user proceeds through the Wallace workflow, the relevant guidance texts can be found to the right of the  Results tab in the Visualization panel.

If more support is needed, the Support tab in the orange navigation bar at the top  provides links to the Wallace homepage, Google group, GitHub, and email.

#### **Saving and Reproducing Results**
Some users may wish to stop an analysis and restart it later. To do so, the option to save the workflow progress as an RDS file is found in the Save tab. This file can be loaded into Wallace later using the Intro component’s Load Prior Session tab, to restart the analysis where the user left off. 

Additionally, *Wallace* allows the user to download their results. After each step of analysis (i.e., after running each module), the results for that particular model may be downloaded from the Save tab in the Visualization panel. 

A great quality of *Wallace* is reproducibility. To download the session code or metadata (documenting all of the analyses run to that point in the Wallace session), use the **Reproduce** component. This includes the option of an R Markdown file that can be opened and rerun in R. 

Closing the browser window will terminate the Wallace analysis, but R will remain running. To close Wallace and stop functions running in R, use the power button in the top right corner in the navigation bar.
  
  
#### **References**
Anderson, R. P. (2015). El modelado de nichos y distribuciones: no es simplemente "clic, clic, clic." [With English and French translations: Modeling niches and distributions: it's not just "click, click, click" and La modélisation de niche et de distributions: ce n'est pas juste "clic, clic, clic"]. *Biogeografía*, 8, 4-27. <a href="https://2278aec0-37af-4634-a250-8bb191f1aab7.filesusr.com/ugd/e41566_e8acb6f9c20c44fa9cd729161582857d.pdf" target="_blank">pdf</a>

Anderson, R.P. (2012). Harnessing the world's biodiversity data: promise and peril in ecological niche modeling of species distributions. *Annals of the New York Academy of Sciences*, 1260(1), 66-80. <a href="https://doi.org/10.1111/j.1749-6632.2011.06440.x" target="_blank">DOI:10.1111/j.1749-6632.2011.06440.x</a>

Franklin, J. (2010). *Mapping species distributions*. Cambridge University Press. <a href="https://doi.org/10.1017/CBO9780511810602" target="_blank">DOI:10.1017/CBO9780511810602</a> 

Guisan, A., Thuiller, W., & Zimmermann, N. E. (2017). Habitat suitability and distribution models: With applications in R. Cambridge University Press. <a href="https://doi.org/10.1017/9781139028271" target="_blank">DOI:10.1017/9781139028271</a>

Kass, J.M., Vilela, B., Aiello-Lammens, M.E., Muscarella, R., Merow, C., & Anderson, R.P. (2018). Wallace: A flexible platform for reproducible modeling of species niches and distributions built for community expansion. *Methods in Ecology and Evolution*, 9(4), 1151-1156. <a href="https://doi.org/10.1111/2041-210X.12945" target="_blank">DOI:10.1111/2041-210X.12945</a>

Peterson, A. T. et al. (2022). ENM2020: A Free Online Course and Set of Resources on Modeling Species’ Niches and Distributions. *Biodiversity Informatics*, 17. <a href="https://doi.org/10.17161/bi.v17i.15016" target="_blank">DOI:10.17161/bi.v17i.15016</a> 

Peterson, A. T., Soberón, J., Pearson, R. G., Anderson, R. P., Martínez-Meyer, E., Nakamura, M., & Araújo, M. B. (2011). *Ecological niches and geographic distributions* (MPB-49). Princeton University Press. <a href="https://press.princeton.edu/books/paperback/9780691136882/ecological-niches-and-geographic-distributions-mpb-49" target="_blank">Princeton University Press</a> 

Zurell, D., Franklin, J., König, C., Bouchet, P.J., Dormann, C.F., Elith, J., Fandos, G., Feng, X., Guillera-Arroita, G., Guisan, A., Lahoz-Monfort, J.J., Leitão, P.J., Park, D.S., Peterson, A.T., Rapacciuolo, G., Schmatz, D.R., Schröder, B., Serra-Diaz, J.M., Thuiller, W., Yates, K.L., Zimmermann,N.E., & Merow, C. (2020). A standard protocol for reporting species distribution models. *Ecography*, 43(9), 1261-1277. <a href="https://doi.org/10.1111/ecog.04960" target="_blank">DOI:10.1111/ecog.04960</a> 

