---
title: "xfer"
output: html_document
---

### **Component: Model Transfer**

**ORIENTATION**

Frequently, research questions require the application (or “transfer”) of a model to a geographic region or time period different from those used to build it (e.g., for studies of invasive species or the effects of climate change). **Component: Model Transfer** allows certain functionalities for such transfers, as well as the means for assessing issues regarding environmental conditions not found in the space and time where the model was built (non-analog environments; Williams and Jackson 2007, Fitzpatrick and Hargrove 2009). Wallace currently allows users to transfer a model to: 1) another region (Module: *Transfer to New Extent*), 2) another time period  (Module: *Transfer  to new time*), or 3) a user-provided environment (Module: *Transfer to User environment*). 
Note: Transferring can also be known as a “projection”, but users should not confuse this with the GIS concept of geographic projections.
Furthermore, at present *Wallace* provides some information characterizing the degree to which the environment in the spatial/temporal transfer differs from that used to make the model (Module: *Calculate Environmental Similarity*). For these functionalities, only one transfer can be displayed at a time, and Module: *Calculate Environmental Similarity* can only be run after a transfer has been made.

**REFERENCES**

Fitzpatrick, M.C., & Hargrove, W.W. (2009). The projection of species distribution models and the problem of non-analog climate. *Biodiversity and Conservation*, 18, 2255. <a href="https://doi.org/10.1007/s10531-009-9584-8" target="_blank">DOI: 10.1007/s10531-009-9584-8</a>

Williams, J.W., & Jackson, S.T. (2007). Novel climates, no-analog communities, and ecological surprises. *Frontiers in Ecology and the Environment*, 5(9), 475-482. <a href="https://doi.org/10.1890/070037" target="_blank">DOI: 10.1890/070037</a>
