```{asis, echo = {{occs_paleoDb_knit}}, eval = {{occs_paleoDb_knit}}, include = {{occs_paleoDb_knit}}}
### Obtain Occurrence Data
You searched the paleobioDB database for *`r "{{spName}}"`*, limited to `r {{occsNumPB_rmd}}` records in the {{timeInterval_rmd}}. 
```

```{r, echo = {{occs_paleoDb_knit}}, include = {{occs_paleoDb_knit}}}
# Query selected database for occurrence records
paleoDb_{{spAbr}}<-occs_paleoDb(
  spName = "{{spName}}",
  occNum = {{occsNumPB_rmd}},
  timeInterval = "{{timeInterval_rmd}}")
occs_{{spAbr}} <- paleoDb_{{spAbr}}$cleaned
```
