```{asis, echo = {{poccs_removeByID_knit}}, eval = {{poccs_removeByID_knit}}, include = {{poccs_removeByID_knit}}}
### Process Occurrence Data
Remove the occurrence localities by ID.
```

```{r, echo = {{poccs_removeByID_knit}}, include = {{poccs_removeByID_knit}}}
# remove the rows that match the occIDs selected
occs_{{spAbr}} <- poccs_removeByID(
  occs = occs_{{spAbr}} , 
  removeID = {{removeByID_id_rmd}})
```
