---
title: "espace"
output: html_document
---

### **Component: Characterize Environmental Space**

**ORIENTATION**

The concept of the ecological niche is central to ecology and intersecting fields, yet has seen varied definitions, emphases, and usages (Holt 2009; Soberón & Nakamura 2009). Several definitions have been proposed by different authors depending largely on whether they consider abiotic and/or biotic factors. As originally defined, the Grinnellian niche is determined by the habitat in which the species lives and its associated behavioral adaptations (e.g., the chaparral habitat is the niche of the California thrasher; Grinnell 1917). In contrast, the Eltonian niche (Chase & Leibold 2003) includes the functional role of a species, considering not only the requirements that allow the species to persist but also how it changes the availability of depletable resources (e.g. a beaver modifies both abiotic conditions by building dams and also resources for other species by chopping down trees). Here, we use the Hutchinsonian formalization of the niche which characterizes an n-dimensional hypervolume where a species can persist and reproduce in a mathematical space defined by non-depletable environmental gradients (Hutchinson 1957; see overlap with the Grinnellian conceptualization; Soberón & Nakamura 2009; Peterson et al. 2011).

The **Characterize Environmental Space** component performs analyses and visualizations of the Hutchinsonian niche for two selected species. Wallace currently allows the user to: 1) perform a Principal Components Analysis (PCA; Module: *Environmental Ordination*) to reduce the dimensionality of the original environmental space, 2) calculate the density of occurrences of the species along the two first components of the PCA (Module: *Occurrence Density Grid*), and 3) perform niche-overlap analyses (Module: *Niche Overlap*).


**REFERENCES**

Grinnell, J. (1917). "The niche-relationships of the California Thrasher". *The Auk*, 34(4), 427–433. <a href="https://www.jstor.org/stable/4072262" target="_blank">DOI:10.2307/4072271</a> 

Chase, J.M., & Leibold, M.A. (2003). *Ecological Niches: Linking Classical and Contemporary Approaches*. <a href="https://press.uchicago.edu/ucp/books/book/chicago/E/bo3638660.html" target="_blank">University of Chicago Press.</a>

Holt, R.D. (2009). Bringing the Hutchinsonian niche into the 21st century: Ecological and evolutionary perspectives. *Proceedings of the National Academy of Sciences*, 106(2), 19659-19665. <a href="https://doi.org/10.1073/pnas.0905137106" target="_blank">DOI:10.1073/pnas.0905137106</a>  

Hutchinson, G.E. (1957). "Concluding remarks". *Cold Spring Harbor Symposia on Quantitative Biology*, 22, 415–427. <a href="http://dx.doi.org/10.1101/SQB.1957.022.01.039" target="_blank">DOI:10.1101/SQB.1957.022.01.039</a>  

Peterson, A.T., Soberón, J., Pearson, R.G., Anderson, R.P., Martinez-Meyer, E., Nakamura, M., & Araújo, M.B. (2011). Environmental Data. In: *Ecological Niches and Geographic Distributions*. Princeton, New Jersey: *Monographs in Population Biology*, 49. <a href="https://doi.org/10.23943/princeton/9780691136868.003.0005" target="_blank">Princeton University Press.</a>   

Soberón, J., Nakamura, M. (2009). Niches and distributional areas: Concepts, methods, and assumptions. *Proceedings of the National Academy of Sciences*, 106(2), 19644-19650. <a href="https://doi.org/10.1073/pnas.0901637106" target="_blank">DOI:10.1073/pnas.0901637106</a>  
