### **Module:** ***Remove Occurrences By ID***

**BACKGROUND**

Despite their great utility, aggregated biodiversity occurrence datasets typically contain errors both in identification and in georeferencing. Many, but certainly not all, such errors can be spotted by simple visual inspection of the localities plotted on a map (Gaiji et al. 2013). For example, if a species is known only from high elevation forest, and a few localities from an online database are in a lowland grassland, this suspicious pattern may lead users to exclude these records from the analysis. This module can also be used to narrow the analysis on a regional subset of available records.

**IMPLEMENTATION**

Users can select individual localities for removal from the analysis by specifying the occID. This unique ID, along with some other information, can be viewed by clicking the point on the map. Users are also able to reset the dataset back to the original occurrences. Finally, users can download a .csv file of the edited localities.

**REFERENCES**

Gaiji, S., Chavan, V., Ariño, A.H., Otegui, J., Hobern, D., Sood, R., & Robles, E. (2013). Content assessment of the primary biodiversity data published through GBIF network: status, challenges and potentials. *Biodiversity Informatics*, 8(2), 94-172. <a href="https://doi.org/10.17161/bi.v8i2.4124" target="_blank">DOI: 10.17161/bi.v8i2.4124</a>  
