```{asis, echo = {{model_bioclim_knit}}, eval = {{model_bioclim_knit}}, include = {{model_bioclim_knit}}}
### Build and Evaluate Niche Model
Generating a species distribution model using the bioclim algorithm as implemented in ENMeval V2.0. 
```

```{r, echo = {{model_bioclim_knit}}, include = {{model_bioclim_knit}}}
# Run bioclim model for the selected species
model_{{spAbr}} <- model_bioclim(
  occs =  occs_{{spAbr}},
  bg = bgEnvsVals_{{spAbr}}, 
  user.grp = groups_{{spAbr}}, 
  bgMsk = bgMask_{{spAbr}})
```
