```{asis, echo = {{espace_occDens_knit}}, eval = {{espace_occDens_knit}}, include = {{espace_occDens_knit}}}
### Environmental space 
Calculating the part of environmental space more densly populated by species & the availability of environmental conditions in the background for  *`r "{{spName1}}"`* & *`r "{{spName2}}"`*
```

```{r, echo = {{espace_occDens_knit}}, include = {{espace_occDens_knit}}}
# Create density grid
espace_occDens_{{multAbr}} <- espace_occDens(
  sp.name1 = "{{spName1}}",
  sp.name2 = "{{spName2}}", 
  pca = espace_pca_{{multAbr}}) 
# Plots
graphics::par(mfrow = c(1,2))
ecospat.plot.nicheDEV(espace_occDens_{{multAbr}}[["{{spName1}}"]], 
                            title = "{{spName1}}")
ecospat.plot.nicheDEV(espace_occDens_{{multAbr}}[["{{spName2}}"]], 
                            title = "{{spName2}}")
```
