### **Module:** ***User-specified Study Region***

**BACKGROUND**

Users may want to use a background selection region that they have created themselves for use in the *Wallace* analysis.

**IMPLEMENTATION** 

Users may upload either a .csv file (with columns for longitude and latitude specifying polygon vertices), or a shapefile (three files: .shp, .shx, .dbf).
