```{asis, echo = {{vis_responsePlot_knit & vis_maxnet_knit}}, eval = {{vis_responsePlot_knit & vis_maxnet_knit}}, include = {{vis_responsePlot_knit & vis_maxnet_knit}}}
### Visualize
Visualize response curves from "{{alg_rmd}}" model.
```

```{r, echo = {{vis_responsePlot_knit & vis_maxnet_knit}}, include = {{vis_responsePlot_knit & vis_maxnet_knit}}}
# Retrieve env variables
n <- mxNonzeroCoefs(model_{{spAbr}}@models[["{{curModel_rmd}}"]], "maxnet")

# Create response curves
for (i in n) {
maxnet::response.plot(
  model_{{spAbr}}@models[["{{curModel_rmd}}"]],
  v = i,
  type = "cloglog")
}
```

```{asis, echo = {{vis_responsePlot_knit & !vis_maxnet_knit}}, eval = {{vis_responsePlot_knit & !vis_maxnet_knit}}, include = {{vis_responsePlot_knit & !vis_maxnet_knit}}}
### Visualize
Visualize response curves from "{{alg_rmd}}" model.
```

```{r, echo = {{vis_responsePlot_knit & !vis_maxnet_knit }}, include = {{vis_responsePlot_knit & !vis_maxnet_knit}}}
# Retrieve env variables
n <- mxNonzeroCoefs(model_{{spAbr}}@models[["{{curModel_rmd}}"]], "maxent.jar")

# Create response curves
for (i in n) {
predicts::partialResponse(
  model_{{spAbr}}@models[["{{curModel_rmd}}"]],
  var = i)
}
```
