```{asis, echo = {{vis_bioclimPlot_knit}}, eval = {{vis_bioclimPlot_knit}}, include = {{vis_bioclimPlot_knit}}}
### Visualize
Visualize bivariate plot of bioclim model for environmental layers `r {{a_rmd}}` & ,
 `r {{b_rmd}}` and a percentile distribution of  `r {{p_rmd}}`

```

```{r, echo = {{vis_bioclimPlot_knit}}, include = {{vis_bioclimPlot_knit}}}
# Generate a bioclim plot 
vis_bioclimPlot_{{spAbr}} <- vis_bioclimPlot(
  x = model_{{spAbr}}@models$bioclim,
  a = {{a_rmd}},
  b = {{b_rmd}},
  p = {{p_rmd}})
```
