---
title: "occs"
output: html_document
---

### **Component: Obtain Occurrence Data**

**ORIENTATION**

Niche/distributional modeling analyses require georeferenced occurrence records for the species (e.g., with latitude/longitude). At present, **Component: Obtain Occurrence Records** focuses on data documenting the presence of the species (i.e., not any information on its absence or non-detection; Franklin 2010, Chapter 4; Peterson et al. 2011, Chapter 5; Anderson 2012). *Wallace* currently allows users to: 1) obtain present-day occurrence records (from dates in the past century or so) from selected online biodiversity databases and download the information (Module: *Query Database [Present]*), 2) obtain paleontological occurrence records from selected online biodiversity databases and download the information (Module: *Query Database [Paleo]*); 
or 3) upload their own dataset (Module: *User-specified Occurrences*).  
Unlike previous versions of *Wallace*, multiple species now can be uploaded in the same session.

*Note: As of 01 September 2023, Module: Query Database [Paleo] will be temporarily unavailable.*

**REFERENCES**

Anderson, R.P. (2012). Harnessing the world's biodiversity data: promise and peril in ecological niche modeling of species distributions. *Annals of the New York Academy of Sciences*, 1260(1), 66-80. <a href="https://doi.org/10.1111/j.1749-6632.2011.06440.x" target="_blank">DOI: 10.1111/j.1749-6632.2011.06440.x</a>

Franklin, J. (2010). Data for species distribution models: The biological data. In: *Mapping Species Distributions: Spatial Inference and Prediction* (Ecology, Biodiversity and Conservation, pp. 55-75). Cambridge: Cambridge University Press. <a href="https://doi.org/10.1017/CBO9780511810602.007" target="_blank">DOI: 10.1017/CBO9780511810602.007</a>  

Peterson, A.T., Soberón, J., Pearson, R.G., Anderson, R.P., Martinez-Meyer, E., Nakamura, M., & Araújo, M.B. (2011). Species' Occurrence Data. In: *Ecological Niches and Geographic Distributions*. Princeton, New Jersey: Monographs in Population Biology, 49. Princeton University Press. <a href="https://doi.org/10.23943/princeton/9780691136868.003.0005" target="_blank">DOI: 10.23943/princeton/9780691136868.003.0005</a> 
