```{asis, echo = {{vis_maxentEvalPlot_knit}}, eval = {{vis_maxentEvalPlot_knit}}, include = {{vis_maxentEvalPlot_knit}}}
### Visualize
Generate a Maxent evaluation plot using "{{evalPlot_rmd}}" as evaluation statistic.
```

```{r, echo = {{vis_maxentEvalPlot_knit}}, include = {{vis_maxentEvalPlot_knit}}}
# Generate an evaluation plot
maxentEvalPlot_{{spAbr}} <- ENMeval::evalplot.stats(
   model_{{spAbr}},
   "{{evalPlot_rmd}}",
   "rm",
   "fc")
#plot
maxentEvalPlot_{{spAbr}}
```
