```{asis, echo = {{model_maxent_knit}}, eval = {{model_maxent_knit & !cat_envs_knit}}, include = {{model_maxent_knit & !cat_envs_knit}}}
### Build and Evaluate Niche Model
Generating a species distribution model using the `r '{{algMaxent_rmd}}'` algorithm as implemented in ENMeval V2.0 (with clamping = `r {{clampSel_rmd}}`).
For tuning using `r  {{fcs_rmd}}` feature classes and regularization multipliers in the `r {{rms_rmd}}` range increasing by `r {{rmsStep_rmd}}`. Not using any categorical predictor variables. 

```

```{r, echo = {{model_maxent_knit & !cat_envs_knit}}, include = {{model_maxent_knit & !cat_envs_knit}}}
# Run maxent model for the selected species
model_{{spAbr}} <- model_maxent(
  occs = occs_{{spAbr}},
  bg = bgEnvsVals_{{spAbr}},
  user.grp = groups_{{spAbr}}, 
  bgMsk = bgMask_{{spAbr}},
  rms = {{rms_rmd}}, 
  rmsStep = {{rmsStep_rmd}},
  fcs = {{fcs_rmd}},
  clampSel = {{clampSel_rmd}},
  algMaxent = "{{algMaxent_rmd}}",
  parallel = {{parallel_rmd}},
  numCores = {{numCores_rmd}})
```

```{asis, echo = {{model_maxent_knit & cat_envs_knit}}, eval = {{model_maxent_knit & cat_envs_knit}}, include = {{model_maxent_knit & cat_envs_knit}}}
### Build and Evaluate Niche Model
Generating a species distribution model using the `r '{{algMaxent_rmd}}'` algorithm as implemented in ENMeval V2.0 (with clamping = `r {{clampSel_rmd}}`).
For tuning using `r  {{fcs_rmd}}` feature classes and regularization multipliers in the `r {{rms_rmd}}` range increasing by `r {{rmsStep_rmd}}`. Using a total of `r {{catEnvsNum_rmd}}` categorical predictor variables. 
```

```{r, echo = {{model_maxent_knit & cat_envs_knit}}, include = {{model_maxent_knit & cat_envs_knit}}}
# Run maxent model for the selected species
model_{{spAbr}} <- model_maxent(
  occs = occs_{{spAbr}},
  bg = bgEnvsVals_{{spAbr}},
  user.grp = groups_{{spAbr}}, 
  bgMsk = bgMask_{{spAbr}},
  rms = {{rms_rmd}}, 
  rmsStep = {{rmsStep_rmd}},
  fcs = {{fcs_rmd}},
  clampSel = {{clampSel_rmd}},
  algMaxent = "{{algMaxent_rmd}}",
  catEnvs = "{{catEnvs_rmd}}",
  parallel = {{parallel_rmd}},
  numCores = {{numCores_rmd}})
```
