```{asis, echo = {{poccs_thinOccs_knit}}, eval = {{poccs_thinOccs_knit}}, include = {{poccs_thinOccs_knit}}}
### Process Occurrence Data
Thinning the occurrences to  `r "{{thinDist_rmd}}"` km
```

```{r, echo = {{poccs_thinOccs_knit}}, include = {{poccs_thinOccs_knit}}}
# Thin occurrences 
occs_{{spAbr}} <- poccs_thinOccs(
  occs = occs_{{spAbr}}, 
  thinDist = {{thinDist_rmd}})
